'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _flexboxReact = require('flexbox-react');

var _flexboxReact2 = _interopRequireDefault(_flexboxReact);

require('../styles/components/pagination-control.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var PaginationControl = function (_React$Component) {
  (0, _inherits3['default'])(PaginationControl, _React$Component);

  function PaginationControl(props) {
    (0, _classCallCheck3['default'])(this, PaginationControl);

    var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

    _this.state = {
      isPrevPageValid: false,
      isNextPageValid: true,
      currentPage: 1,
      totalItems: props.totalItems,
      lastPage: Math.ceil(props.totalItems / props.perPage)
    };
    _this.nextPage = _this.nextPage.bind(_this);
    _this.prevPage = _this.prevPage.bind(_this);
    _this.validatePage = _this.validatePage.bind(_this);
    _this.resetPagination = _this.resetPagination.bind(_this);
    return _this;
  }

  PaginationControl.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.perPage !== this.props.perPage) {
      this.resetPagination();
    }
  };

  PaginationControl.prototype.resetPagination = function resetPagination() {
    this.setState({
      currentPage: 1,
      isPrevPageValid: false,
      isNextPageValid: true
    });
  };

  PaginationControl.prototype.nextPage = function nextPage() {
    if (this.props.controlsDisabled) {
      return false;
    }
    if (this.state.isNextPageValid) {
      var currentPage = this.state.currentPage;
      this.props.navigateToPage(currentPage + 1);
      this.setState({ currentPage: currentPage + 1 }, this.validatePage);
    }
    return false;
  };

  PaginationControl.prototype.prevPage = function prevPage() {
    if (this.props.controlsDisabled) {
      return false;
    }
    if (this.state.isPrevPageValid) {
      var currentPage = this.state.currentPage;
      this.props.navigateToPage(currentPage - 1);
      this.setState({ currentPage: currentPage - 1 }, this.validatePage);
    }
    return false;
  };

  PaginationControl.prototype.validatePage = function validatePage() {
    var currentPage = this.state.currentPage;
    this.setState({
      isNextPageValid: currentPage < this.state.lastPage,
      isPrevPageValid: currentPage > 1
    });
  };

  PaginationControl.prototype.render = function render() {
    var disabledClass = '';
    if (this.props.controlsDisabled) {
      disabledClass = 'disabled';
    }
    var currentCount = this.state.currentPage * this.props.perPage > this.state.totalItems ? this.state.totalItems : this.state.currentPage * this.props.perPage;
    return _react2['default'].createElement(
      _flexboxReact2['default'],
      { flexDirection: 'row', className: 'consoles__pagination' },
      _react2['default'].createElement(
        _flexboxReact2['default'],
        { className: 'pagination__button pagination__prev ' + disabledClass + ' ' + (this.state.isPrevPageValid ? '' : 'disabled'), onClick: this.prevPage },
        _react2['default'].createElement('i', { className: 'arrow_carrot-left', 'aria-hidden': 'true' })
      ),
      _react2['default'].createElement(
        _flexboxReact2['default'],
        { className: 'pagination__count', alignItems: 'center' },
        _react2['default'].createElement(
          'span',
          { className: 'count__current' },
          currentCount
        ),
        _react2['default'].createElement(
          'span',
          null,
          'of'
        ),
        _react2['default'].createElement(
          'span',
          { className: 'count__total' },
          this.state.totalItems
        )
      ),
      _react2['default'].createElement(
        _flexboxReact2['default'],
        { className: 'pagination__button pagination__next ' + disabledClass + ' ' + (this.state.isNextPageValid ? '' : 'disabled'), onClick: this.nextPage },
        _react2['default'].createElement('i', { className: 'arrow_carrot-right', 'aria-hidden': 'true' })
      )
    );
  };

  return PaginationControl;
}(_react2['default'].Component);

PaginationControl.propTypes = {
  totalItems: _react2['default'].PropTypes.number.isRequired,
  navigateToPage: _react2['default'].PropTypes.func.isRequired,
  perPage: _react2['default'].PropTypes.number.isRequired,
  controlsDisabled: _react2['default'].PropTypes.bool
};

exports['default'] = PaginationControl;
module.exports = exports['default'];
//# sourceMappingURL=PaginationControl.js.map