'use strict';

exports.__esModule = true;

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Rect = require('./Rect');

var _Rect2 = _interopRequireDefault(_Rect);

var _BarChartTooltip = require('./BarChartTooltip');

var _BarChartTooltip2 = _interopRequireDefault(_BarChartTooltip);

var _utils = require('../Chart/utils');

var ChartUtils = _interopRequireWildcard(_utils);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var d3 = (0, _assign2['default'])({}, require('d3-time-format'), require('d3-axis'));
var array = _react.PropTypes.array,
    number = _react.PropTypes.number,
    object = _react.PropTypes.object,
    string = _react.PropTypes.string,
    bool = _react.PropTypes.bool;

var BarChart = function (_React$Component) {
  (0, _inherits3['default'])(BarChart, _React$Component);

  function BarChart(props) {
    (0, _classCallCheck3['default'])(this, BarChart);

    var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

    _this.state = {
      tooltip: {
        display: false,
        color: null,
        title: '',
        data: { key: '', value: '' },
        pos: { x: '', y: '' }
      }
    };
    _this.showToolTip = _this.showToolTip.bind(_this);
    _this.hideToolTip = _this.hideToolTip.bind(_this);
    return _this;
  }

  BarChart.prototype.showToolTip = function showToolTip(e) {
    this.setState({
      tooltip: {
        display: true,
        color: e.target.getAttribute('fill'),
        title: this.props.tooltipTitle,
        data: {
          key: e.target.getAttribute('data-key'),
          value: e.target.getAttribute('data-value')
        },
        pos: {
          x: e.target.getAttribute('cx'),
          y: e.target.getAttribute('cy')
        }
      }
    });
  };

  BarChart.prototype.hideToolTip = function hideToolTip() {
    this.setState({
      tooltip: {
        display: false,
        data: { key: '', value: '' }
      }
    });
  };

  BarChart.prototype.render = function render() {
    var _props = this.props,
        barPadding = _props.barPadding,
        borderRadius = _props.borderRadius,
        height = _props.height,
        margin = _props.margin,
        width = _props.width,
        xDataType = _props.xDataType,
        showXLabel = _props.showXLabel,
        showIcon = _props.showIcon;

    var innerWidth = width - (margin.left + margin.right);
    var innerHeight = height - (margin.top + margin.bottom);
    var transform = 'translate(-' + margin.left + ', ' + margin.top + ')';
    var xScale = null;
    var data = JSON.parse((0, _stringify2['default'])(this.props.data));
    var xScaleTimeLineData = JSON.parse((0, _stringify2['default'])(this.props.data));

    if (this.props.xDataType === 'date') {
      var parseDate = d3.timeParse('%m-%d-%Y %H:%M:%S');
      data.forEach(function (d) {
        d.x = parseDate(d.x);
      });
      xScaleTimeLineData.forEach(function (d) {
        d.x = parseDate(d.x);
      });

      xScale = ChartUtils.xScaleBand(data, innerWidth, barPadding);
    } else {
      xScale = ChartUtils.xScaleLinear(data, innerWidth, barPadding);
    }

    var yScale = ChartUtils.yScaleLinear(data, innerHeight, 0);

    return _react2['default'].createElement(
      'div',
      { className: 'bar-chart__container svg-overflow-visible' },
      _react2['default'].createElement(
        'svg',
        { width: width, height: height },
        _react2['default'].createElement(
          'g',
          { transform: transform },
          _react2['default'].createElement(_Rect2['default'], {
            borderRadius: borderRadius,
            data: data,
            fill: '#4898da',
            hideToolTip: this.hideToolTip,
            innerHeight: innerHeight,
            showToolTip: this.showToolTip,
            transform: transform,
            xScale: xScale,
            yScale: yScale,
            xDataType: xDataType,
            showXLabel: showXLabel,
            showIcon: showIcon,
            XLabelFontSize: this.props.XLabelFontSize
          }),
          _react2['default'].createElement(_BarChartTooltip2['default'], { tooltip: this.state.tooltip, yScale: yScale })
        )
      )
    );
  };

  return BarChart;
}(_react2['default'].Component);

BarChart.propTypes = {
  barPadding: number,
  borderRadius: number,
  data: array.isRequired,
  height: number,
  margin: object,
  width: number,
  xDataType: string,
  showXLabel: bool,
  showIcon: bool,
  tooltipTitle: string,
  XLabelFontSize: string
};

BarChart.defaultProps = {
  barPadding: 0.1,
  borderRadius: 3,
  height: 70,
  margin: { top: 0, right: 5, bottom: -5, left: 10 },
  width: 200,
  xDataType: 'month',
  showXLabel: false,
  showIcon: false,
  tooltipTitle: '',
  XLabelFontSize: '16'
};

exports['default'] = BarChart;
module.exports = exports['default'];
//# sourceMappingURL=BarChart.js.map