'use strict';

exports.__esModule = true;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _palette = require('../../../palette');

var _palette2 = _interopRequireDefault(_palette);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var d3 = (0, _assign2['default'])({}, require('d3-time-format'));

var array = _react.PropTypes.array,
    func = _react.PropTypes.func,
    number = _react.PropTypes.number,
    string = _react.PropTypes.string;


var warningIconUri = require('../../../assets/icon_eh_warning.svg');
var criticalIconUri = require('../../../assets/icon_eh_error.svg');

var Rect = function Rect(props) {
  var borderRadius = props.borderRadius,
      data = props.data,
      fill = props.fill,
      innerHeight = props.innerHeight,
      xScale = props.xScale,
      yScale = props.yScale;


  var rects = data.map(function (d, i) {
    var xDataKey = d.x;
    var xDateLabel = '';
    var iconUri = '';
    var fillColor = fill;
    if (props.xDataType === 'date') {
      xDataKey = d3.timeFormat('%m/%d/%Y (%H:%M)')(d.x);
      xDateLabel = d3.timeFormat('%m/%d')(d.x);
    }
    if (d.currentState === 'warning') {
      fillColor = _palette2['default'].yellow;
      iconUri = warningIconUri;
    } else if (d.currentState === 'critical') {
      fillColor = _palette2['default'].red;
      iconUri = criticalIconUri;
    }
    return _react2['default'].createElement(
      'g',
      { key: i + '-g' },
      _react2['default'].createElement('rect', {
        className: 'shadow',
        fill: fillColor,
        height: innerHeight - yScale(d.y),
        key: i,
        cx: xScale(d.x) + 5,
        cy: yScale(d.y),
        rx: borderRadius,
        ry: borderRadius,
        width: xScale.bandwidth(),
        x: xScale(d.x),
        y: yScale(d.y),
        'data-key': xDataKey,
        'data-value': d.y,
        onMouseEnter: props.showToolTip,
        onMouseOut: props.hideToolTip
      }),
      props.showIcon ? _react2['default'].createElement('image', {
        xmlns: 'http://www.w3.org/2000/svg',
        xlinkHref: iconUri,
        x: xScale(d.x),
        key: i + '-i',
        y: (innerHeight - yScale(d.y)) / 2,
        width: xScale.bandwidth(),
        height: '50px',
        className: 'svgicon',
        cx: xScale(d.x),
        cy: yScale(d.y),
        pointerEvents: 'none'

      }) : '',
      props.showXLabel ? _react2['default'].createElement(
        'text',
        { fontSize: props.XLabelFontSize, x: xScale(d.x) + xScale.bandwidth() / 2, key: i + '-t', width: xScale.bandwidth(), y: innerHeight + 13, fill: _palette2['default'].grey, textAnchor: 'middle' },
        xDateLabel
      ) : ''
    );
  });

  return _react2['default'].createElement(
    'g',
    null,
    rects
  );
};

Rect.propTypes = {
  borderRadius: number,
  data: array.isRequired,
  fill: string,
  innerHeight: number.isRequired,
  hideToolTip: func.isRequired,
  showToolTip: func.isRequired,
  xDataType: string.isRequired,
  xScale: func.isRequired,
  yScale: func.isRequired,
  showXLabel: _react2['default'].PropTypes.bool,
  showIcon: _react2['default'].PropTypes.bool,
  XLabelFontSize: string
};

Rect.defaultProps = {
  borderRadius: 3,
  fill: _palette2['default'].blue,
  showXLabel: false,
  showIcon: false,
  XLabelFontSize: '16'
};

exports['default'] = Rect;
module.exports = exports['default'];
//# sourceMappingURL=Rect.js.map